summaryrefslogtreecommitdiffstats
path: root/bksys/kde.py
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-11-05 21:46:14 -0500
committerTimothy Pearson <[email protected]>2011-11-05 21:46:14 -0500
commitf46b2c7ae17c2bba1fc15c2d35ac60510328e09d (patch)
tree351c95f806a33662c727b90be341deaad84d43aa /bksys/kde.py
parent8589554e2e71c8f148fade567a2b2b2e52cd80f4 (diff)
downloadwlassistant-f46b2c7ae17c2bba1fc15c2d35ac60510328e09d.tar.gz
wlassistant-f46b2c7ae17c2bba1fc15c2d35ac60510328e09d.zip
Rename kde libraries to tde
Diffstat (limited to 'bksys/kde.py')
-rw-r--r--bksys/kde.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/bksys/kde.py b/bksys/kde.py
index 23343c8..95361c9 100644
--- a/bksys/kde.py
+++ b/bksys/kde.py
@@ -4,8 +4,8 @@
import os, re, types
from SCons.Script.SConscript import SConsEnvironment
# Returns the name of the shared object (eg: libkdeui.so.4)
# referenced by a libtool archive (like libkdeui.la)
def getSOfromLA(lafile):
contents = open(lafile, 'r').read()
match = re.search("^dlname='([^']*)'$", contents, re.M)
@@ -116,8 +116,8 @@ def detect_kde(env):
else:
try:
tmplibdir = os.popen(kde_config+' --expandvars --install lib').read().strip()
- libkdeuiSO = env.join(tmplibdir, getSOfromLA(env.join(tmplibdir,'/libkdeui.la')) )
- m = re.search('(.*)/lib/libtqt.*', os.popen('ldd ' + libkdeuiSO + ' | grep libtqt').read().strip().split()[2])
+ libtdeuiSO = env.join(tmplibdir, getSOfromLA(env.join(tmplibdir,'/libtdeui.la')) )
+ m = re.search('(.*)/lib/libtqt.*', os.popen('ldd ' + libtdeuiSO + ' | grep libtqt').read().strip().split()[2])
except: m=None
if m:
qtdir = m.group(1)
@@ -4,8 +4,8 @@
import os, re, types
from SCons.Script.SConscript import SConsEnvironment
-# Returns the name of the shared object (eg: libkdeui.so.4)
-# referenced by a libtool archive (like libkdeui.la)
+# Returns the name of the shared object (eg: libtdeui.so.4)
+# referenced by a libtool archive (like libtdeui.la)
def getSOfromLA(lafile):
contents = open(lafile, 'r').read()